@@ -295,7 +295,21 @@ def deploy_main(args):
 
     if args.which == "resetdata":
         if args.Service:
-            print(args.Service)
+            pkg_path = False
+            if not os.path.exists(args.tarFile):
+                cwd = [os.getcwd(), check_result.deploy_dir]
+                for d in cwd:
+                    pkg_path = find(d, args.tarFile, file=True)
+                    if pkg_path:
+                        break
+            else:
+                pkg_path = os.path.join(os.getcwd(), args.tarFile)
+            if not pkg_path:
+                print(Helper().FILE_NOT_FOUND)
+                exit(2)
+            PKG = os.path.dirname(pkg_path)
+            ID = os.path.basename(pkg_path).split(".")[0]
+            PKG_DIR = pkg_path.split(".")[0]
 
             package_info = read_form_json_file(PROJECT_INFO_FILE)
             deploy_package = DeployPackageHandler(package_info["PKG"], package_info["ID"])
@@ -304,60 +318,67 @@ def deploy_main(args):
             # 解析
             parse_package = deploy_package.parse()
             service_package = parse_package.service
-
+            services = {
+                "license": LicenseController,
+                "mage": MageController,
+                "entcmd": CommanderController,
+                "chatbot": ChatbotController,
+                "nlp": NlpController,
+                "captcha": CaptchaController,
+                "ocr": OcrStandardController,
+                "ocr_seal": SealController,
+                "entuc": UserCenterController,
+                "dataservice": DataServiceController,
+                "notice": NoticeController,
+                "ocr_text": OcrTextController,
+                "ocr_text_cpu": OcrTextCpuController,
+                "ocr_table": OcrTableController,
+                "ocr_idcard": OcrIdcardController,
+                "rpa-collaboration": RpaCollaborationController,
+                "ocr_layout_analysis": OcrLayoutAnalysisController,
+                "ocr_bizlicense": OcrBizlicenseController,
+                "nlp_layoutlm": NlpLaYouTlmController,
+            }
+            middlewares = {
+                "etcd": (EtcdConfigHandler, EtcdController),
+                "minio": (MinioConfigHandler, MinioController),
+                "redis": (RedisConfigHandler, RedisController),
+                "mysql": (MysqlConfigHandler, MysqlController),
+                "elasticsearch": (EsConfigHandler, EsController),
+                "rabbitmq": (RabbitmqConfigHandler, RabbitmqController),
+            }
+            dir_dict = {}
+            for i in os.listdir(PKG_DIR):
+                # 匹配项目名称，找出服务部署包
+                # entcmd_6.0-20221117155526-test
+                project_name_find = re.findall(r'(.*)_\d\.{0,3}\d{0,3}-\d{14}(.*?).tar.gz', i)
+                if project_name_find:
+                    dir_dict[project_name_find[0][0]] = i
             for s in service_package:
-                dir_dict = {}
-                for i in os.listdir(PKG_DIR):
-                    # 匹配项目名称，找出服务部署包
-                    project_name_find = re.findall(r'(.*)-\d\.{0,3}\d{0,3}_\d{14}.tar.gz', i)
-                    if project_name_find:
-                        dir_dict[project_name_find[0]] = i
-
-                if s.project_name in dir_dict:
+                if args.Service in dir_dict and args.Service == s.project_name:
                     s.unpack(package_name=dir_dict[s.project_name])
                     service_path = s.parse()
-                    middleware_list = service_path.config.middleware
+                    deploy_package = DeployPackageHandler(PKG, ID)
 
-                    middlewares = {
-                        "etcd": (EtcdConfigHandler, EtcdController),
-                        "minio": (MinioConfigHandler, MinioController),
-                        "redis": (RedisConfigHandler, RedisController),
-                        "mysql": (MysqlConfigHandler, MysqlController),
-                        "elasticsearch": (EsConfigHandler, EsController),
-                        "rabbitmq": (RabbitmqConfigHandler, RabbitmqController),
-                    }
+                    # 解析部署包
+                    parse_package = deploy_package.parse()
+                    middleware_package = parse_package.middleware
+                    middleware_list = service_path.config.middleware
 
                     for mid in middleware_list:
                         path = middleware_package.parse()[mid]
                         config = middlewares[mid][0]()
                         middleware = middlewares[mid][1](check_result, config, path)
                         middleware.remove()
-                        middleware.deploy()
-
-                    if args.Service == "chatbot":
-                        deploy_service = ChatbotController(check_result, service_path)
-                        deploy_service.init_chatbot_mysql.set_force("chatbot", True)
-                        deploy_service.init_chatbot_mysql()
-                        deploy_service.project_pod_check()
-                        deploy_service.init_chatbot_entuc_clients.set_force("chatbot", True)
-                        deploy_service.init_chatbot_entuc_clients()
-                        exit(0)
-                    elif args.Service == "entcmd":
-                        deploy_service = CommanderController(check_result, service_path)
-                        deploy_service.init_commander_mysql.set_force("entcmd", True)
-                        deploy_service.init_commander_mysql()
-                        deploy_service.init_commander_rabbitmq.set_force("entcmd", True)
-                        deploy_service.init_commander_rabbitmq()
-                        deploy_service.init_commander_minio.set_force("entcmd", True)
-                        deploy_service.init_commander_minio()
-                        deploy_service.project_pod_check()
-                        exit(0)
-                    elif args.Service == "rpa-collaboration":
-                        deploy_service = RpaCollaborationController(check_result, service_path)
-                        exit(0)
-                    elif args.Service == "notice":
-                        deploy_service = NoticeController(check_result, service_path)
-                        exit(0)
+                        middleware.deploy(True)
+                
+            for s in service_package:
+                if s.project_name in dir_dict:
+                    s.unpack(package_name=dir_dict[s.project_name])
+                    service_path = s.parse()
+                    deploy_service = services[s.project_name](check_result, service_path)
+                    deploy_service.rebuild_data()
+                    
     if args.which == "test":
         if args.Service:
             print(args.Service)
@@ -398,4 +419,4 @@ def deploy_main(args):
                     elif args.Service == "notice":
                         deploy_service = NoticeController(check_result, service_path)
                         deploy_service.run_apptest()
-                        exit(0)
+                        exit(0)
\ No newline at end of file
