@@ -90,5 +90,6 @@ class EsController(MiddlewareInterface):
             self.start()
             self._check()
 
-    def deploy(self):
+    def deploy(self, force=False):
+        self.deploy_es.set_force(force)
         self.deploy_es()
