@@ -64,5 +64,6 @@ class EtcdController(MiddlewareInterface):
 		self.start()
 		self._check()
 
-	def deploy(self):
+	def deploy(self, force=False):
+		self.deploy_etcd.set_force(force)
 		self.deploy_etcd()
