@@ -104,5 +104,6 @@ class IdentityController(MiddlewareInterface):
         self.send_docker_compose_file()
         self.restart()
 
-    def deploy(self):
+    def deploy(self, force=False):
+        self.deploy_identity.set_force(force)
         self.deploy_identity()
