@@ -210,5 +210,6 @@ class MysqlController(MiddlewareInterface):
             self._check()
             self.create_mysql_service_kubernetes()
 
-    def deploy(self):
+    def deploy(self, force=False):
+        self.deploy_mysql.set_force(force)
         self.deploy_mysql()
