@@ -116,5 +116,6 @@ class RabbitmqController(MiddlewareInterface):
             self._check()
         self.create_rabbitmq_service_kubernetes()
 
-    def deploy(self):
+    def deploy(self, force=False):
+        self.deploy_rabbitmq.set_force(force)
         self.deploy_rabbitmq()
