@@ -204,3 +204,13 @@ class CommanderController(ServiceInterface):
         self.project_pod_check()
         # self.init_commander_entuc_clients()
         self.commander_apptest()
+
+    def rebuild_data(self):
+        self.init_commander_mysql.set_force(True)
+        self.init_commander_mysql()
+        self.init_commander_rabbitmq.set_force(True)
+        self.init_commander_rabbitmq()
+        self.init_commander_minio.set_force(True)
+        self.init_commander_minio()
+        self.restart_service(self.namespace)
+        self.project_pod_check()
\ No newline at end of file
