@@ -845,3 +845,10 @@ class ServiceInterface:
                     if res.status_code > 204:
                         log.error("rabbitmq vhost error.")
                         exit(2)
+
+    def restart_service(self, namespace="all_namespaces"):
+        kube = KubeModel()
+        kube.restart_deploy(namespace=namespace)
+        
+    def rebuild_data(self):
+        pass
\ No newline at end of file
