@@ -38,6 +38,11 @@ def Args():
                                 default=False, help="删除所有服务")
     delete_parser.set_defaults(which='delete')
 
+    reset_parser = subparsers.add_parser('resetdata', help='重置中间件数据')
+    reset_parser.add_argument("--service", dest="Service", type=str, help="指定需要自动化测试的项目")
+    reset_parser.add_argument('-t', '--tar-file', dest="tarFile", type=str, help="指定部署压缩包")
+    reset_parser.set_defaults(which='resetdata')
+
     apptest_parser = subparsers.add_parser('apptest', help='自动化功能相关参数')
     apptest_parser.add_argument("--service", dest="Service", type=str, help="指定需要自动化测试的项目")
     apptest_parser.set_defaults(which='test')
