@@ -17,7 +17,8 @@ from paramiko.ssh_exception import AuthenticationException, NoValidConnectionsEr
 
 
 def monkey_sudo(password, cmd):
-    cmd = "echo '{}' | sudo -S {}".format(password, cmd)
+    # cmd = "echo '{}' | sudo -S {}".format(password, cmd)
+    cmd = "echo '{}' | sudo -p '' -S {}".format(password, cmd)
     return cmd
 
 
@@ -72,6 +73,7 @@ class SSHConnect(object):
             try:
                 if self.password:
                     self.obj.connect(hostname=self.hostip, port=self.port, username=self.username,
+                                     allow_agent=False, look_for_keys=False,
                                      password=self.password,
                                      timeout=self.timeout)
                     self.objsftp = self.obj.open_sftp()
