@@ -294,14 +294,16 @@ def walk_sql_path(path):
 
 def status_me(proj, force=False):
     def run_func(fn):
-        def set_force(force):
+        def set_force(value):
             nonlocal force
-            force = force
+            force = value
 
         def wrapper(self, *args, **kwargs):
             status = Status()
             if force:
+                log.info(Helper().RUN_STEP.format(proj, fn.__name__))
                 fn(self, *args, **kwargs)
+                status.update_status(proj, fn.__name__, status.STATUS_SUCCESS)
             else:
                 if status.get_status(proj, fn.__name__) == status.STATUS_SUCCESS:
                     log.info(Helper().SKIP_STEP.format(proj, fn.__name__))
